==> comt-2.6.0.tar.gz: comt-2.6.0/TRADEMARK_CLAUSE.md <==
Trademark clause
================

Additionnal trademark clause
----------------------------

### Trademark

co-ment(R) is a registered trademark of Philippe Aigrain.

### Additional trademark clause to the GNU Affero GPLv3 license for the COMT software

As authorized by the [GNU AGPLv3](http://www.fsf.org/licensing/licenses/agpl.html "Affero GPLv3 license text") license, users of the COMT software can only make use of the co-ment trademark in compliance with the regulation of use (see below).

Regulation of use for the co-ment(R) trademark
----------------------------------------------

### Sopinspace

Sopinspace is a SARL (limited liability company) with a capital of 15000 €, registered in France under the number RCS Paris B 451 436 604 with VAT number FR92 451 436 604. Sopinspace(R) is a registered trademark. Postal address: 4, passage de la Main d'Or, F-75011 Paris, France.

### Definitions

For the application of this regulation:

1. *Country of operation* designate the country in which an activity (such as operating a Web service or distributing software) covered by the co-ment trademark classes is conducted.
2. *Commercial purpose* designates any activity associated with a direct commercial transaction (for instance users or organisations paying to access a service or using a software) or an indirect commercial income (for instance advertising funded sites).
3. *Commercial entity* designates any company (whatever its statute) as defined by the general rules of accounting and tax in the country of operation.
4. *Non-for-profit activity* designates an activity conducted without a direct or indirect aim of profit. Any activity having a commercial purpose as defined above is excluded.
5. *Non-for-profit organisation* any organisation recognized in the country of operation as having on of the common statutes for non-for-profit organizations.
6. *General interest organisation* designates an organization whose main purpose is to serve the public.
7. *Sopinspace co-ment sites* designates any website operated by Sopinspace whose domain name contains *co-ment* and any subdomain of these sites.

### Rules

Use of the co-ment trademark by a commercial entity or for any commercial purpose is forbidden without written authorization of the tramemark holder.

Non-for-profit organisations are welcome to make use of the co-ment trademark within source code, documentation or user interfaces for their non-for-profit activities when operating Web services or software based on the COMT platform or developing activities making use of Sopinspace's co-ment(R) Web services, provided that:

* they add the customary (R) sign to mentions of the trademark, and,
* they include at least one visible link to one of Sopinspace's co-ment sites when mentioning the trademark in documentation or user interfaces.

General interest organisations may be granted the same authorization on written request to Philippe Aigrain, Sopinspace, 4 passage de la Main d'Or, F-75011 Paris France, depending of the tramemark holder's evaluation.

==> comt-2.6.1.tar.gz: comt-2.6.1/TRADEMARK_CLAUSE.md <==
# Trademark clause

## Additionnal trademark clause

### Trademark

co-ment(R) is a registered trademark of Philippe Aigrain.

### Additional trademark clause to the GNU Affero GPLv3 license for the COMT software

As authorized by the [GNU AGPLv3](http://www.fsf.org/licensing/licenses/agpl.html "Affero GPLv3 license text") license, users of the COMT software can only make use of the co-ment trademark in compliance with the regulation of use (see below).

## Regulation of use for the co-ment(R) trademark

### Sopinspace

Sopinspace is a SARL (limited liability company) with a capital of 15000 €, registered in France under the number RCS Paris B 451 436 604 with VAT number FR92 451 436 604. Sopinspace(R) is a registered trademark. Postal address: 4, passage de la Main d'Or, F-75011 Paris, France.

### Definitions

For the application of this regulation:

1. *Country of operation* designate the country in which an activity (such as operating a Web service or distributing software) covered by the co-ment trademark classes is conducted.
2. *Commercial purpose* designates any activity associated with a direct commercial transaction (for instance users or organisations paying to access a service or using a software) or an indirect commercial income (for instance advertising funded sites).
3. *Commercial entity* designates any company (whatever its statute) as defined by the general rules of accounting and tax in the country of operation.
4. *Non-for-profit activity* designates an activity conducted without a direct or indirect aim of profit. Any activity having a commercial purpose as defined above is excluded.
5. *Non-for-profit organisation* any organisation recognized in the country of operation as having on of the common statutes for non-for-profit organizations.
6. *General interest organisation* designates an organization whose main purpose is to serve the public.
7. *Sopinspace co-ment sites* designates any website operated by Sopinspace whose domain name contains *co-ment* and any subdomain of these sites.

### Rules

Use of the co-ment trademark by a commercial entity or for any commercial purpose is forbidden without written authorization of the tramemark holder.

Non-for-profit organisations are welcome to make use of the co-ment trademark within source code, documentation or user interfaces for their non-for-profit activities when operating Web services or software based on the COMT platform or developing activities making use of Sopinspace's co-ment(R) Web services, provided that:

* they add the customary (R) sign to mentions of the trademark, and,
* they include at least one visible link to one of Sopinspace's co-ment sites when mentioning the trademark in documentation or user interfaces.

General interest organisations may be granted the same authorization on written request to Philippe Aigrain, Sopinspace, 4 passage de la Main d'Or, F-75011 Paris France, depending of the tramemark holder's evaluation.
